@@ -25,5 +25,5 @@ namespace torch_ext {
 std::tuple<at::Tensor, at::Tensor> fp4_quantize(at::Tensor const& self,
                                                 at::Tensor const& globalScale, int64_t sfVecSize,
                                                 bool sfUseUE8M0, bool isSfSwizzledLayout,
-                                                bool isSf8x4Layout);
+                                                bool isSf8x4Layout, bool enable_pdl);
 }  // namespace torch_ext
