@@ -11,7 +11,6 @@ from torch.utils.cpp_extension import _get_cuda_arch_flags
 
 from .activation import act_func_def_str, gen_act_and_mul_module
 from .cascade import gen_cascade_module
-from .comm.nvshmem import gen_nvshmem_module
 from .fp4_quantization import gen_fp4_quantization_sm100_module
 from .fused_moe import gen_cutlass_fused_moe_sm100_module
 from .gemm import gen_gemm_module, gen_gemm_sm90_module, gen_gemm_sm100_module
@@ -372,6 +371,9 @@ def gen_all_modules(
 
     if add_comm:
         from .comm import gen_trtllm_comm_module, gen_vllm_comm_module
+        from .comm.nvshmem import gen_nvshmem_module
+
+        jit_specs.append(gen_nvshmem_module())
 
         if has_sm100:
             jit_specs.append(gen_trtllm_comm_module())
@@ -381,7 +383,6 @@ def gen_all_modules(
         jit_specs += [
             gen_cascade_module(),
             gen_norm_module(),
-            gen_nvshmem_module(),
             gen_page_module(),
             gen_quantization_module(),
             gen_rope_module(),
@@ -580,7 +581,7 @@ def main():
     gencode_flags = _get_cuda_arch_flags()
 
     def has_sm(compute: str, version: str) -> bool:
-        if not any("compute_90" in flag for flag in gencode_flags):
+        if not any(compute in flag for flag in gencode_flags):
             return False
         if torch.version.cuda is None:
             return True
