@@ -1,13 +1,13 @@
 import functools
 from types import SimpleNamespace
-from typing import Tuple
+from typing import Optional, Tuple
 
 import torch
 
 from .jit import JitSpec
 from .jit import env as jit_env
 from .jit import gen_jit_spec, sm100a_nvcc_flags
-from .utils import register_custom_op, register_fake_op
+from .utils import device_support_pdl, register_custom_op, register_fake_op
 
 
 def gen_mxfp8_quantization_sm100_module() -> JitSpec:
@@ -50,6 +50,7 @@ def get_mxfp8_quantization_sm100_module():
         input: torch.Tensor,
         is_sf_swizzled_layout: bool = True,
         alignment: int = 32,
+        enable_pdl: Optional[bool] = None,
     ) -> Tuple[torch.Tensor, torch.Tensor]:
         """Quantize input tensor to MxFP8 format.
 
@@ -57,6 +58,8 @@ def get_mxfp8_quantization_sm100_module():
             input (torch.Tensor): Input tensor of shape [M, K] with dtype fp16/bf16/fp8_quantized.
             is_sf_swizzled_layout (bool, optional): Whether to use swizzled layout for scale factors. Defaults to True.
             alignment (int, optional): sfVecSize. Defaults to 32. Note that alignment is not used in the host kernel.
+            enable_pdl (Optional[bool], optional): Whether to enable PDL (Programmatic Dependent Launch).
+                If None, automatically detects based on device capability. Defaults to None.
         Returns:
             Tuple[torch.Tensor, torch.Tensor]: A tuple containing:
                 - Quantized tensor of shape [M, K] with dtype FLOAT8_E4M3
@@ -68,10 +71,13 @@ def get_mxfp8_quantization_sm100_module():
                 is_sf_swizzled_layout,
             )
         else:
+            if enable_pdl is None:
+                enable_pdl = device_support_pdl(input.device)
             return module.mxfp8_quantize(
                 input,
                 is_sf_swizzled_layout,
                 alignment,
+                enable_pdl,
             )
 
     @register_fake_op("flashinfer::mxfp8_quantize_sm100")
@@ -129,6 +135,7 @@ def mxfp8_quantize(
     input: torch.Tensor,
     is_sf_swizzled_layout: bool = True,
     alignment: int = 32,
+    enable_pdl: Optional[bool] = None,
 ) -> Tuple[torch.Tensor, torch.Tensor]:
     """Quantize input tensor to MxFP8 format.
 
@@ -139,6 +146,8 @@ def mxfp8_quantize(
         input (torch.Tensor): Input tensor of shape [M, K] with dtype fp16/bf16/fp8_quantized.
         is_sf_swizzled_layout (bool, optional): Whether to use swizzled layout for scale factors. Defaults to True.
         alignment (int, optional): sfVecSize. Defaults to 32.
+        enable_pdl (Optional[bool], optional): Whether to enable PDL (Programmatic Dependent Launch).
+            If None, automatically detects based on device capability. Defaults to None.
     Returns:
         Tuple[torch.Tensor, torch.Tensor]: A tuple containing:
             - Quantized tensor of shape [M, K] with dtype FLOAT8_E4M3
@@ -147,10 +156,13 @@ def mxfp8_quantize(
     sf_vec_size = 32
 
     assert input.shape[-1] % sf_vec_size == 0
+    if enable_pdl is None:
+        enable_pdl = device_support_pdl(input.device)
     x_q, sf = get_mxfp8_quantization_sm100_module().mxfp8_quantize_sm100(
         input,
         is_sf_swizzled_layout,
         alignment,
+        enable_pdl,
     )
     return x_q, sf
 
