@@ -231,15 +231,15 @@ class BatchMLAPagedAttentionWrapper:
 
         Parameters
         ----------
-        qo_indptr : torch.Tensor
+        qo_indptr : torch.IntTensor
             The indptr of the query/output tensor, shape: ``[batch_size + 1]``.
             For decoding attention, the length of each query is 1, and the content
             of the tensor should be ``[0, 1, 2, ..., batch_size]``.
-        kv_indptr : torch.Tensor
+        kv_indptr : torch.IntTensor
             The indptr of the paged kv-cache, shape: ``[batch_size + 1]``.
-        kv_indices : torch.Tensor
+        kv_indices : torch.IntTensor
             The page indices of the paged kv-cache, shape: ``[kv_indptr[-1]]`` or larger.
-        kv_len_arr : torch.Tensor
+        kv_len_arr : torch.IntTensor
             The query length of each request, shape: ``[batch_size]``.
         num_heads : int
             The number of heads in query/output tensor.
@@ -260,6 +260,18 @@ class BatchMLAPagedAttentionWrapper:
         use_profiler : bool, optional
             Whether to enable intra-kernel profiler, default is False.
         """
+
+        for tensor, name in [
+            (kv_len_arr, "kv_len_arr"),
+            (kv_indptr, "kv_indptr"),
+            (qo_indptr, "qo_indptr"),
+            (kv_indices, "kv_indices"),
+        ]:
+            if tensor.dtype != torch.int32:
+                raise ValueError(
+                    f"Expected {name}.dtype == torch.int32, got {tensor.dtype}"
+                )
+
         self._cached_module = get_batch_mla_module(
             self._backend,
             q_data_type,
